==> react-title-multisize-1.12.0.tgz: package/lib/index.js <==
import PropTypes from 'prop-types';
import React from 'react';
import cx from 'classnames'; // Map object for title sizes and HTML Tags.

var TAG_FOR_SIZE = {
  xl: 'h1',
  l: 'h2',
  m: 'h3',
  s: 'h4',
  xs: 'h5'
};

/**
 * Builds an HTML/React Element depending on the size declared (xs: H5, s: H4, m: H3, l: H2, xl = H1).
 * @param size {string} Size (xs, s, m, l, xl) of title element.
 * @param className {string} CSS classNames to apply to element.
 * @param content {React.ElementType} Children of title element. Could be an element (HTML/React Element), string, or an array of both.
 * @returns {any} React Title Element.
 */
var buildTitleElement = function buildTitleElement(size, className, content) {
  var Tag = TAG_FOR_SIZE[size];
  return content && React.createElement(Tag, {
    className: className
  }, content);
};

var TitleMultisize = function TitleMultisize(_ref) {
  var className = _ref.className,
      _ref$orientation = _ref.orientation,
      orientation = _ref$orientation === void 0 ? 'vertical' : _ref$orientation,
      postTitle = _ref.postTitle,
      _ref$postTitleSize = _ref.postTitleSize,
      postTitleSize = _ref$postTitleSize === void 0 ? 's' : _ref$postTitleSize,
      preTitle = _ref.preTitle,
      _ref$preTitleSize = _ref.preTitleSize,
      preTitleSize = _ref$preTitleSize === void 0 ? 'xs' : _ref$preTitleSize,
      title = _ref.title,
      _ref$titleSize = _ref.titleSize,
      titleSize = _ref$titleSize === void 0 ? 'xl' : _ref$titleSize;
  return React.createElement("div", {
    className: cx('sui-TitleMultisize', "sui-TitleMultisize--" + orientation, className)
  }, buildTitleElement(preTitleSize, cx('sui-TitleMultisize-preTitle', "sui-TitleMultisize-preTitle--" + preTitleSize), preTitle), buildTitleElement(titleSize, cx('sui-TitleMultisize-title', "sui-TitleMultisize-title--" + titleSize), title), buildTitleElement(postTitleSize, cx('sui-TitleMultisize-postTitle', "sui-TitleMultisize-postTitle--" + postTitleSize), postTitle));
};

TitleMultisize.displayName = 'TitleMultisize';
export default TitleMultisize;

==> react-title-multisize-1.14.0.tgz: package/lib/index.js <==
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import cx from 'classnames'; // Map object for title sizes and HTML Tags.

var TAG_FOR_SIZE = {
  xl: 'h1',
  l: 'h2',
  m: 'h3',
  s: 'h4',
  xs: 'h5'
};

/**
 * Builds an HTML/React Element depending on the size declared (xs: H5, s: H4, m: H3, l: H2, xl = H1).
 * @param size {string} Size (xs, s, m, l, xl) of title element.
 * @param className {string} CSS classNames to apply to element.
 * @param content {React.ElementType} Children of title element. Could be an element (HTML/React Element), string, or an array of both.
 * @returns {any} React Title Element.
 */
var buildTitleElement = function buildTitleElement(size, className, content) {
  var Tag = TAG_FOR_SIZE[size];
  return content && /*#__PURE__*/_jsx(Tag, {
    className: className,
    children: content
  });
};

var TitleMultisize = function TitleMultisize(_ref) {
  var className = _ref.className,
      _ref$orientation = _ref.orientation,
      orientation = _ref$orientation === void 0 ? 'vertical' : _ref$orientation,
      postTitle = _ref.postTitle,
      _ref$postTitleSize = _ref.postTitleSize,
      postTitleSize = _ref$postTitleSize === void 0 ? 's' : _ref$postTitleSize,
      preTitle = _ref.preTitle,
      _ref$preTitleSize = _ref.preTitleSize,
      preTitleSize = _ref$preTitleSize === void 0 ? 'xs' : _ref$preTitleSize,
      title = _ref.title,
      _ref$titleSize = _ref.titleSize,
      titleSize = _ref$titleSize === void 0 ? 'xl' : _ref$titleSize;
  return /*#__PURE__*/_jsxs("div", {
    className: cx('sui-TitleMultisize', "sui-TitleMultisize--" + orientation, className),
    children: [buildTitleElement(preTitleSize, cx('sui-TitleMultisize-preTitle', "sui-TitleMultisize-preTitle--" + preTitleSize), preTitle), buildTitleElement(titleSize, cx('sui-TitleMultisize-title', "sui-TitleMultisize-title--" + titleSize), title), buildTitleElement(postTitleSize, cx('sui-TitleMultisize-postTitle', "sui-TitleMultisize-postTitle--" + postTitleSize), postTitle)]
  });
};

TitleMultisize.displayName = 'TitleMultisize';
export default TitleMultisize;
